#### ---- functions and data
source("functions.R")
load("radon.RData")

#### ---- data description
dim(radon) 
g<-radon[,1]
y<-radon[,2]
ng<-table(g)
ybg<-tapply(y,g,mean) 
sdg<-tapply(y,g,sd) 


#### ---- EDA
anova(lm(y~as.factor(g)) )        

library(lme4)
summary(lm(y~as.factor(g)))
s2<-summary(lm(y~as.factor(g)))$sigma^2
fit_lme<-lmer( y ~ 1 + (1|g) )

## --  Levene's test
d<-abs(y-tapply(y,g,median)[g])
anova( lm(d~as.factor(g)) )


#### ---- EFAB t intervals for heteroscedastic groups 
alpha<-.05
UCI<-FCI<-BCI<-NULL  
for(j in 1:length(ng))
{ 

  uci<-fci<-c(-Inf,Inf)
  if(ng[j]>1)
  {
   
    ## -- eBayes estimates from other groups 
    gamj<-ebayes_fabt(y[g!=j],g[g!=j]) 

    ## -- FAB-t interval 
    fci<-fabt_ci(ybg[j],sdg[j],ng[j],gamj$mu,gamj$t2,gamj$nu0,gamj$s20,alpha=alpha)
 
    ## -- UMA-t interval
    uci<- ybg[j]+c(-1,1)*sdg[j]*qt(1-alpha/2,ng[j]-1)/sqrt(ng[j]) 
    
    ## -- Bayes credible intervals
    ethj<-(gamj$mu/gamj$t2+ybg[j]*ng[j]/sdg[j]^2)/
      (1/gamj$t2+ng[j]/sdg[j]^2)
    psdj<-1/sqrt(1/gamj$t2 + ng[j]/sdg[j]^2 )   
    bci<-ethj+c(-1,1)*psdj*qt(1-alpha/2,ng[j]-1)
    
  }

  BCI<-rbind(BCI,bci)  
  UCI<-rbind(UCI,uci)
  FCI<-rbind(FCI,fci) 
  cat(j,"\n") 

}

#### -- plot
#pdf("radon.pdf",height=4,width=9,family="Times")  
setEPS() ; postscript("../art/radon.eps",height=4,width=9,family="Times")
par(mar=c(3,3,1,1),mgp=c(1.75,.75,0)) 
bg<-which(ng>=3)
ybarg<-tapply(y,g,mean)
plot(range(ybarg[bg]),range(c(UCI[bg,],FCI[bg,])),type="n", 
      xlab=expression(bar(y)),ylab=expression(theta),las=1) 

segments(ybarg[bg],BCI[bg,1],ybarg[bg],BCI[bg,2],col="lightgray",lwd=4) 
segments(ybarg[bg],FCI[bg,1],ybarg[bg],FCI[bg,2]) 

points(UCI[bg,1]~ybarg[bg],pch="-")
points(UCI[bg,2]~ybarg[bg],pch="-")

abline(v=summary(fit_lme)$coef[1],col="gray",lty=2 )  
abline(h=summary(fit_lme)$coef[1],col="gray",lty=2 )

abline(0,1,col="gray",lty=2)
dev.off() 

#### -- comparison 

# comparison between usual CI and FAB CI
WR<-( UCI[,2]-UCI[,1] )/( FCI[,2]-FCI[,1] ) 
# number of times when usual CI is wider than FAB CI
sum(WR>1,na.rm=T) 
sum(!is.na(WR)) 
mean(WR,na.rm=TRUE) 
tapply(y,g,mean)[ which( WR<1 ) ]
ng[ which( WR<1 ) ] 

# comparison between EB CI and FAB CI
WR2<-( BCI[,2]-BCI[,1] )/( FCI[,2]-FCI[,1] )
WR2<-WR2[-which(FCI[,2]==Inf)]
# number of times when EB CI is wider than FAB CI
sum(WR2>1,na.rm=T)
sum(!is.na(WR2)) 
# mean width ratio of EB CI to FAB CI
mean(WR2,na.rm=TRUE) 
tapply(y,g,mean)[ which( WR2<1 ) ]
ng[ which( WR2<1 ) ] 







#### ---- simulation results
COVER<-WIDTH<-matrix(0,ncol=3,nrow=85) 
nsim<-0
for(sgroup in (1:10) )
{
  load(paste0("simres",sgroup,"_alpha",alpha)) 
  COVER[,1]<-COVER[,1]+ucover 
  COVER[,2]<-COVER[,2]+fcover 
  COVER[,3]<-COVER[,3]+bcover  

  WIDTH[,1]<-WIDTH[,1]+uwidth 
  WIDTH[,2]<-WIDTH[,2]+fwidth
  WIDTH[,3]<-WIDTH[,3]+bwidth

  nsim<-nsim+s  
} 
COVER<-COVER/nsim ; WIDTH<-WIDTH/nsim 


#### ----
FCCI<-BCCI<-NULL
for(j in 1:nrow(COVER))
{  
  fci<-bci<-c(NA,NA)  
  if(!is.na(ucover[j]) )
  {
  fci<-binom.test(COVER[j,2]*nsim,nsim,p=.95)
  bci<-binom.test(COVER[j,3]*nsim,nsim,p=.95)
   
  FCCI<-rbind(FCCI,fci$conf.int)
  BCCI<-rbind(BCCI,bci$conf.int)
  }
}






#### ---- plots
#pdf("radon_simV4.pdf",height=3.5,width=8.5,family="Times")
setEPS() ; postscript("../art/radon_sim.eps",height=3.25,width=8,family="Times")
par(mfrow=c(1,2),mar=c(3,3,1,1),mgp=c(1.85,.75,0))

## -- expected widths given theta
plot(ybg,WIDTH[,2]/WIDTH[,1],
     ylim=range(c(WIDTH[,2]/WIDTH[,1],WIDTH[,3]/WIDTH[,1]),na.rm=T),
     pch=16,xlab=expression(theta),ylab="Width ratio",las=1)
points(ybg,WIDTH[,3]/WIDTH[,1],col="gray",pch=16)
segments(ybg,WIDTH[,2]/WIDTH[,1],ybg,WIDTH[,3]/WIDTH[,1])
abline(h=1,lty=2)
#legend(2.2,1.25,legend=c("FAB","EB"),pch=c(16,16),col=c("black","gray")  )
abline(v=mean(ybg),lty=2,col="gray")

## -- coverage of Bayes intervals
plot(range(ybg),100*range(BCCI),type="n",
     xlab=expression(theta),ylab="Empirical Bayes coverage percent",las=1) 

segments(ybg,100*BCCI[,1],ybg,100*BCCI[,2] ) #,col="darkgray" )   
#segments(ybg+.05,FCCI[,1],ybg+.05,FCCI[,2] )  

abline(h=100*(1-alpha),lty=2)
abline(v=mean(ybg),lty=2,col="gray")
dev.off()





sum( WIDTH[,2]>WIDTH[,1],na.rm=TRUE )

apply(WIDTH,2,mean,na.rm=TRUE) 
apply(COVER,2,mean,na.rm=TRUE)

range(COVER[,3],na.rm=T )




